@@ -1,4 +1,4 @@
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 import sys, os
 from time import sleep
@@ -7,10 +7,10 @@ def delete_line(num):
 	CURSOR_UP_ONE = '\x1b[1A' 
 	ERASE_LINE = '\x1b[2K' 
 	for i in range(num):
-    
+    sys.stdout.write(CURSOR_UP_ONE) 
+		sys.stdout.write(ERASE_LINE)
 def clear():
 	os.system('clear')
-  
 def slow_print(*strings, time = 0.045, sep = ' ', end = '\n', file = sys.stdout):	
 	num = len(strings)
 	for string in strings:
